/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.control.activity.task;

import org.objectweb.fractal.api.control.NameController;

/**
 * Abstract Task class. Provides a name controller interface to give a name to a
 * task.
 */
public abstract class AbstractTask implements Task, NameController
{

  /**
   * An integer that can be used with some schedulers to specify that the task
   * should be executed again.
   */
  protected static final Integer EXECUTE_AGAIN  = new Integer(0);

  /**
   * An integer that can be used with some schedulers to specify that the task
   * should not be executed again.
   */
  protected static final Integer STOP_EXECUTING = new Integer(-1);
  protected String               taskName;

  /**
   * Create a Task with the specified name.
   * 
   * @param name the name of the task
   */
  public AbstractTask(String name)
  {
    this.taskName = name;
  }

  /**
   * @see org.objectweb.fractal.api.control.NameController#getFcName()
   */
  public String getFcName()
  {
    return taskName;
  }

  /**
   * @see org.objectweb.fractal.api.control.NameController#setFcName(java.lang.String)
   */
  public void setFcName(String name)
  {
    taskName = name;
  }

  /**
   * @see java.lang.Object#toString()
   */
  public String toString()
  {
    return taskName;
  }
}