/**
 * Dream
 * Copyright (C) 2003-2004 INRIA Rhone-Alpes
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Contact: dream@objectweb.org
 *
 * Initial developer(s): Matthieu Leclercq
 * Contributor(s): 
 */

package org.objectweb.dream.util;

import java.util.Iterator;
import java.util.NoSuchElementException;

/**
 * Iterator class that iterates over an array of iterator.
 */
public class MultipleIterator implements Iterator
{

  Iterator[] iters;
  int        i;

  /**
   * Creates a new <code>MultipleIterator</code>.
   * 
   * @param iters the array of iterator over which this iterator will iterate.
   */
  public MultipleIterator(Iterator[] iters)
  {
    this.iters = iters;
    i = 0;
  }

  /**
   * @see java.util.Iterator#remove()
   */
  public void remove()
  {
    iters[i].remove();
  }

  /**
   * @see java.util.Iterator#hasNext()
   */
  public boolean hasNext()
  {
    while (i < iters.length)
    {
      boolean hasNext = iters[i].hasNext();
      if (hasNext)
      {
        return true;
      }
      i++;
    }
    return false;
  }

  /**
   * @see java.util.Iterator#next()
   */
  public Object next()
  {
    if (!iters[i].hasNext())
    {
      i++;
      while (i < iters.length)
      {
        if (iters[i].hasNext())
        {
          return iters[i].next();
        }
        i++;
      }
      throw new NoSuchElementException();
    }

    return iters[i].next();
  }
}